@@ -1,4 +1,5 @@
-from django.forms import ModelForm, RegexField
+from django.forms import ModelForm, RegexField, ModelChoiceField
+from django.contrib.auth.models import Group
 from samklang_pages.models import Page
 from django.utils.translation import ugettext_lazy as _
 
@@ -12,7 +13,8 @@ class PageForm(ModelForm):
             error_message = _("This value must contain only letters, numbers,"
                 " underscores, dashes or slashes."),
             )
+    group = ModelChoiceField(Group.objects, empty_label=_("Public"), required=False, label=_("Read permission"))
 
     class Meta:
         model = Page
-        exclude = ('content_html', 'user')
+        exclude = ('content_html', 'user', 'site')
